/*
 * Asterisk -- An open source telephony toolkit.
 *
 * Copyright (C) 1999 - 2006, Digium, Inc.
 *
 * See http://www.asterisk.org for more information about
 * the Asterisk project. Please do not directly contact
 * any of the maintainers of this project for assistance;
 * the project provides a web site, mailing lists and IRC
 * channels for your use.
 *
 * This program is free software, distributed under the terms of
 * the GNU General Public License Version 2. See the LICENSE file
 * at the top of the source tree.
 */

/*! \file
 *
 * \brief Dialplan group functions check if a context exists
 *
 * \author Gregory Nietsky AKA irroot <gregory@networksentry.co.za>
 * 
 * \ingroup functions
 */

#include "asterisk.h"

ASTERISK_FILE_VERSION(__FILE__, "$Revision: 90470 $")

#include <stdlib.h>
#include <string.h>
/*
include <stdio.h>
include <sys/types.h>
*/

#include "asterisk/module.h"
#include "asterisk/channel.h"
#include "asterisk/pbx.h"
#include "asterisk/app.h"
/*
include "asterisk/utils.h"
include "asterisk/logger.h"
*/

static int isexten_function_read(struct ast_channel *chan, char *cmd, char *data, char *buf, size_t len) {
	char *parse;

	AST_DECLARE_APP_ARGS(args,
		AST_APP_ARG(context);
		AST_APP_ARG(exten);
		AST_APP_ARG(priority);
	);
	parse = ast_strdupa(data);
	AST_STANDARD_APP_ARGS(args, parse);

	if (args.priority)
		if (ast_findlabel_extension(chan, args.context, args.exten, args.priority, chan->cid.cid_num))
			strcpy(buf,"1");
		else
			strcpy(buf,"0");
	else
		if (ast_exists_extension(chan, args.context, args.exten, 1, chan->cid.cid_num))
			strcpy(buf,"1");
		else
			strcpy(buf,"0");
	return 0;
}

static struct ast_custom_function isexten_function = {
	.name = "ISEXTEN",
	.syntax = "ISEXTEN(context|extension[|priority])",
	.synopsis = "Checks the existance of a dialplan target.",
	.desc = "Returns a 1 if the target exits otherwise 0.\n",
	.read = isexten_function_read,
};

static int unload_module(void)
{
	int res = 0;

	res |= ast_custom_function_unregister(&isexten_function);

	return res;
}

static int load_module(void)
{
	int res = 0;

	res |= ast_custom_function_register(&isexten_function);

	return res;
}

AST_MODULE_INFO_STANDARD(ASTERISK_GPL_KEY, "Dialplan Context/Extension/Priority Checking Functions");
